# Installation of Wai-Annotations

To install wai-annotations issue the following command using pip:

```
pip install wai.annotations
```

wai-annotations comes with a number of built-in formats/conversions, but if additional ones are required, install
these as well alongside wai-annotations.
